﻿///////////////////////////////////////////////////////////////////////

// AE_submitToRush.jsx
// Version 2.0
//
// This script brings up the submit-afterfx interface from within AfterFX
// with the values for project file, frame range, comp name, etc. preset in the form.
//
// To install, save this script as "/Applications/Adobe After Effects/Scripts/AE_submitToRush.jsx"
// It will then automatically show up in the Files -> Scripts menu of AE.
//
// TODO: Currently supports Mac OSX only. Should be modified to support Windows.
//
// by Simon Bjork with the help of Greg Ercolano.
// Based on a Nuke script by Greg Ercolano.
//
// February 2011: Version 1.4 -- Simon Bjork and Greg Ercolano
// July 2011: Version 1.5 -- Greg Ercolano -- added check if no project file is loaded, code cleanup
// August 2011: Version 2.0 -- Rewrite of script by Simon Björk. Fixed a lot of issues in earlier versions.

///////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////

// CUSTOMIZE THIS PATHNAME FOR YOUR ENVIRONMENT
//                      |
//                     \|/
//                      v
var rushSubmitScript = "/Volumes/misc/rushscripts/submit-afterfx.pl";   // Path to submit-afterfx.pl on your server.
var cpus   = "+any=5@100";  // Default cpu specification.
var batch = "yes";  // Enable or disable batch frames.
var batchFrames  = 5;   // default frame batching value,
var aeVersion = "CS5";  // AE version.

///////////////////////////////////////////////////////////////////////

function submitToRush() {

// Check if scripts are allowed to write files.
var securitySetting = app.preferences.getPrefAsLong("Main Pref Section", "Pref_SCRIPTING_FILE_NETWORK_SECURITY");
    if ( securitySetting != 1) {
        alert ("Please enable 'Allow scripts to write files and to newtwork' in the preferences.");
        return;
        }

// Check if the Rush submit script exists.
var submitScript = File(rushSubmitScript);
    if (!submitScript.exists){
        alert("Can't find the Rush submit script. Did you enter the correct path? Current path: " + rushSubmitScript + ".")
        return;
        }

// Check if a project file is loaded.
if(!app.project.file){
    // No scene file loaded? Just open default submit form
    alert("No project file loaded.\n" + "Using previously rendered submit defaults.");
    // Run submit script with no arguments. Assume defaults from last submit.
    var cmd = "perl " + rushSubmitScript + " " + " > /dev/null 2>&1 < /dev/null &";
    var out = system.callSystem(cmd);
    return;
    }

// Check if a composition is selected.
    if(app.project.selection == 0) {
        alert("Please select a composition.");
        return;
    }

// Check composition frame range.
var myComp = app.project.activeItem;
var frameDur = app.project.activeItem.frameDuration;
var dispStartFrame = app.project.displayStartFrame;
var compDispFrame = app.project.activeItem.displayStartTime/frameDur;
var compFrameDur = myComp.duration/frameDur;

    if(dispStartFrame == 0) {
        var firstFrame = compDispFrame;
        var lastFrame = compFrameDur + firstFrame -1;
            }else{    
                var firstFrame = dispFrame + 1;
                var lastFrame = compFrameDur + firstFrame -1;
                }

// AE project file. 
var projectPath = app.project.file.fsName.toString();
var aePF = app.project.file.name.replace(/%20/gi," ");
var aePFnoExt = aePF.substring(0,aePF.length-4);

// More variables.
var compName = app.project.activeItem.name;
var jobTitle = aePFnoExt + "_" + compName;

// Rush commands.
var cmd      = "perl " + rushSubmitScript + " " +
                    "-field JobTitle: \""  + jobTitle + "\" " +
                    "-field Frames: "    + firstFrame  + "-" + lastFrame + " " +
                    "-field ScenePath: \""  + projectPath + "\" " +
                    "-field CompName: \""  + compName + "\" " +
                    "-field BatchClip: "  + batch  + " " +
                    "-field BatchFrames: "  + batchFrames + " " +
                    "-field AEVersion: "  + aeVersion  + " " +
                    "-field Cpus: \"" + cpus + "\" " + " > /dev/null 2>&1 < /dev/null &";
                
var out = system.callSystem(cmd);

} // function submitToRush() {

// Run script.
submitToRush();
      